@@ -7,10 +7,10 @@ use IPC::Cmd qw//;
 
 use vars qw/$VERSION/;
 BEGIN {
-    $VERSION = '1.00';
+    $VERSION = '1.02';
 }
 
-use constant ISWIN32 => ($^O =~ /win32/i ? 1 : 0);
+#use constant ISWIN32 => ($^O =~ /win32/i ? 1 : 0);
 
 =head1 NAME
 
@@ -46,6 +46,8 @@ works the same way for C<@INC> entries that are plain paths.
 Requires one named parameter: C<perl>, the path to the perl
 interpreter to query for information.
 
+Optional parameter: C<debug =E<gt> 1> enables the debugging mode.
+
 =cut
 
 sub new {
@@ -59,6 +61,7 @@ sub new {
         perl => undef,
         config => undef,
         inc => undef,
+        ($args{debug} ? (debug => 1) : ()),
     };
     bless $self => $class;
 
@@ -73,6 +76,8 @@ sub new {
         );
     }
 
+    warn "Using perl '$perl'" if $self->{debug};
+
     $self->{perl} = $perl;
 
     return $self;
@@ -88,7 +93,8 @@ sub _perl_to_file {
 
     # Build up a set of file names (not command names).
     if ($^O ne 'VMS') {
-        $ .= $Config{_exe};
+      $perl .= $Config{_exe}
+        unless $perl =~ m/\Q$Config{_exe}$/i;
     }
 
     return $perl if -f $perl and -x _;
@@ -134,13 +140,23 @@ foreach my $k (keys %Config) {
  print qq{$ek\n$ev\n};
 }
 HERE
+
+    warn "Running the following code:\n---$code\n---" if $self->{debug};
+
+    $code =~ s/\s+$//;
     $code =~ s/\n/ /g;
 
-    my ($success, $error_code, undef, $buffer, $error) = IPC::Cmd::run(
-        command => [
-            $perl, '-e', (ISWIN32 ? "\"$code\"" : "'$code'")
-        ],
+    my @command = (
+      $perl, '-e', $code
     );
+    warn "Running the following command: '@command'" if $self->{debug};
+
+    my ($success, $error_code, undef, $buffer, $error) = IPC::Cmd::run(
+        command => \@command,
+    );
+
+    warn "Returned buffer is:\n---\n".join("\n",@$buffer)."\n---" if $self->{debug};
+    warn "Returned error buffer is:\n---\n".join("\n",@$error)."\n---" if $self->{debug};
 
     if (not $success) {
         croak(
@@ -148,6 +164,9 @@ HERE
         );
     }
 
+    warn "Returned buffer is:\n---\n".join("\n",@$buffer)."\n---" if $self->{debug};
+    warn "Returned error buffer is:\n---\n".join("\n",@$error)."\n---" if $self->{debug};
+
     my %Config;
     my @data = split /\n/, join '', @$buffer;
     while (@data) {
@@ -205,12 +224,18 @@ foreach my $inc (@INC) {
   print qq{$i\n};
 }
 HERE
+    warn "Running the following code:\n---$code\n---" if $self->{debug};
+
+    $code =~ s/\s+$//;
     $code =~ s/\n/ /g;
 
+    my @command = (
+      $perl, '-e', $code
+    );
+    warn "Running the following command: '@command'" if $self->{debug};
+
     my ($success, $error_code, undef, $buffer, $error) = IPC::Cmd::run(
-        command => [
-            $perl, '-e', (ISWIN32 ? "\"$code\"" : "'$code'")
-        ],
+        command => \@command,
     );
 
     if (not $success) {
@@ -219,6 +244,9 @@ HERE
         );
     }
 
+    warn "Returned buffer is:\n---\n".join("\n",@$buffer)."\n---" if $self->{debug};
+    warn "Returned error buffer is:\n---\n".join("\n",@$error)."\n---" if $self->{debug};
+
     my @inc;
     my @data = split /\n/, join '', @$buffer;
     foreach my $line (@data) {
@@ -256,7 +284,7 @@ Steffen Mueller, E<lt>smueller@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 by Steffen Mueller
+Copyright (C) 2007-2008 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.6 or,
